pg.ddx.io pgsql-hackers@postgresql.org mailing list archive
help / color / mirror / Atom feed From: Andrey Lepikhov <a.lepikhov@postgrespro.ru>
To: Etsuro Fujita <etsuro.fujita@gmail.com>
Cc: Zhihong Yu <zyu@yugabyte.com>
Cc: Justin Pryzby <pryzby@telsasoft.com>
Cc: Amit Langote <amitlangote09@gmail.com>
Cc: tanghy.fnst@fujitsu.com, Ashutosh Bapat <ashutosh.bapat.oss@gmail.com>
Cc: Pg Hackers <pgsql-hackers@postgresql.org>
Cc: Tomas Vondra <tomas.vondra@enterprisedb.com>
Cc: houzj.fnst@fujitsu.com
Subject: Re: Fast COPY FROM based on batch insert
Date: Fri, 28 Oct 2022 16:53:17 +0600
Message-ID: <ccf33ea3-65b4-72dd-6bfb-337fb448433e@postgrespro.ru> (raw )
In-Reply-To: <CAPmGK14AVJExx9NZNNRy1iKeXVQRikm_vrqdYsj6ELX8yFLXpg@mail.gmail.com >
References: <TYAPR01MB2990B8451B4C725242E270F7FE979@TYAPR01MB2990.jpnprd01.prod.outlook.com >
<05bc8819-3e53-d884-a0d0-a17ffa5febef@postgrespro.ru >
<CAPmGK15jd6gEt_XyswQ4uEG6XVdz9DNC5uqW1KK=1A_ehLTEYw@mail.gmail.com >
<09ff35ff-291f-d9e9-a0ed-55e6bb9732fc@postgrespro.ru >
<CAPmGK15WWjXsyBE05vDjvi37012WTiW-j=-Y8Uo=VqPRpsbOgg@mail.gmail.com >
<CAPmGK15ZqOfE4N0PknZMzW96DRdZOA8ih_7591JMqAZu-Nhiiw@mail.gmail.com >
<CALNJ-vQd-bMrydDzUg5+fr9w+gTnErCADhk3KSi72_RCcKJw=Q@mail.gmail.com >
<CAPmGK17pyQgsz9zy9T4avRNw8TY74T5-v1n0vSUgSn8tmjGgVg@mail.gmail.com >
<CAPmGK1476Smi59cszMZM7z7oeFJ5NF9MOChmHjsF2OZ48eyg-w@mail.gmail.com >
<CAPmGK160mQENUMOjMa03-QRR77wiZrA375tiT6KY_wP-hsNu2Q@mail.gmail.com >
<e618cae7-b421-2e1f-d777-38946a669879@postgrespro.ru >
<CAPmGK16aE1oO-AP_rjGLc8yf_OK_eoF1mQqsHVEzFu2WptXLMQ@mail.gmail.com >
<a8d6717a-0c28-9bc5-7a93-eb36f1cb7975@postgrespro.ru >
<CAPmGK14XGLHKBfr639Y96X0LwWXzX+73oj=USRx7N2FC5FNVnQ@mail.gmail.com >
<CAPmGK14AVJExx9NZNNRy1iKeXVQRikm_vrqdYsj6ELX8yFLXpg@mail.gmail.com >
On 28/10/2022 16:12, Etsuro Fujita wrote:
> On Thu, Oct 13, 2022 at 6:58 PM Etsuro Fujita <etsuro.fujita@gmail.com> wrote:
>> I have committed the patch after tweaking comments a little bit further.
>
> I think there is another patch that improves performance of COPY FROM
> for foreign tables using COPY FROM STDIN, but if Andrey (or anyone
> else) want to work on it again, I think it would be better to create a
> new CF entry for it (and start a new thread for it). So I plan to
> close this in the November CF unless they think otherwise.
>
> Anyway, thanks for the patch, Andrey! Thanks for reviewing, Ian and Zhihong!
Thanks,
I studied performance of this code in comparison to bulk INSERTions.
This patch seems to improve speed of insertion by about 20%. Also, this
patch is very invasive. So, I don't have any plans to work on it now.
--
regards,
Andrey Lepikhov
Postgres Professional
view thread (39+ messages) latest in thread
Message-ID: <ccf33ea3-65b4-72dd-6bfb-337fb448433e@postgrespro.ru>
Permalink: ../ccf33ea3-65b4-72dd-6bfb-337fb448433e@postgrespro.ru/
Also on: postgresql.org/message-id/ccf33ea3-65b4-72dd-6bfb-337fb448433e@postgrespro.ru
copy link · copy postgr.es
reply Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Reply to all the recipients using the --to and --cc options:
reply via email
To: pgsql-hackers@postgresql.org
Cc: a.lepikhov@postgrespro.ru, etsuro.fujita@gmail.com, zyu@yugabyte.com, pryzby@telsasoft.com, amitlangote09@gmail.com, ashutosh.bapat.oss@gmail.com, tomas.vondra@enterprisedb.com, houzj.fnst@fujitsu.com
Subject: Re: Fast COPY FROM based on batch insert
In-Reply-To: <ccf33ea3-65b4-72dd-6bfb-337fb448433e@postgrespro.ru>
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox